@@ -57,3 +57,18 @@ def rhythm_blur(a, n=3):
 def rhythm_similarity(a, b, n=3):
     return cosine_similarity(rhythm_blur(a, n), rhythm_blur(b, n))
 
+
+def get_segmented_data(pitched_dataset, drum_dataset, epsilon=5e-2, drum_similarity=cosine_similarity):
+    segmented_pitches = []
+    segmented_drums = []
+    head = 0
+    for i, (prev_drum, next_drum) in enumerate(zip(drum_dataset[:-1], drum_dataset[1:])):
+        if drum_similarity(prev_drum.flatten(), next_drum.flatten()) < 1 - epsilon:
+            segmented_pitches.append(pitched_dataset[head:i + 1])
+            segmented_drums.append(drum_dataset[head:i + 1])
+            head = i + 1
+
+    segmented_pitches.append(pitched_dataset[head:])
+    segmented_drums.append(drum_dataset[head:])
+
+    return segmented_pitches, segmented_drums
